pub fn look_at_quat(eye: Vec3, center: Vec3, up: Vec3) -> QuatExpand description
Returns a Quat view rotation from eye, focal point, and up.
Transforms right-handed world space points into right-handed Y-up view space.
Panics
Will panic if up is not normalized when glam_assert is enabled.