look_to_affine3a

Function look_to_affine3a 

pub fn look_to_affine3a(eye: Vec3, dir: Vec3, up: Vec3) -> Affine3A
Returns an Affine3A view transform from eye, forward direction, and up.

Transforms right-handed world space points into right-handed Y-up view space.

Panics

Will panic if dir or up are not normalized when glam_assert is enabled.